@@ -71,6 +71,9 @@ FAILEDOPERATION_DELETEAUDITFAILERROR = 'FailedOperation.DeleteAuditFailError'
 # 查询数据库代理失败。
 FAILEDOPERATION_DESCRIBEPROXYGROUPERROR = 'FailedOperation.DescribeProxyGroupError'
 
+# 不支持当前操作。
+FAILEDOPERATION_FAILEDOPERATIONERROR = 'FailedOperation.FailedOperationError'
+
 # 获取权限错误。
 FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'
 
@@ -98,6 +101,9 @@ FAILEDOPERATION_PROXYGROUPSTATUSERROR = 'FailedOperation.ProxyGroupStatusError'
 # 查询日志失败。
 FAILEDOPERATION_QUERYLOGERROR = 'FailedOperation.QueryLogError'
 
+# 代理创建中或则已存在，请勿重复创建。
+FAILEDOPERATION_REPEATCREATEPROXYERROR = 'FailedOperation.RepeatCreateProxyError'
+
 # 后台请求服务异常，请您联系客服解决。
 FAILEDOPERATION_RESPONSEVALUEERROR = 'FailedOperation.ResponseValueError'
 
@@ -116,6 +122,9 @@ FAILEDOPERATION_TIMEOUTERROR = 'FailedOperation.TimeoutError'
 # 类型错误，无法执行该操作。
 FAILEDOPERATION_TYPEINCONFLICT = 'FailedOperation.TypeInConflict'
 
+# 该IP已被占用。
+FAILEDOPERATION_VPCIPINUSEERROR = 'FailedOperation.VpcIpInUseError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -458,12 +467,24 @@ OPERATIONDENIED_NOTSUPPORTBASIC = 'OperationDenied.NotSupportBasic'
 # 不支持修改本地root账号host信息。
 OPERATIONDENIED_NOTSUPPORTMODIFYLOCALROOTHOSTERROR = 'OperationDenied.NotSupportModifyLocalRootHostError'
 
+# 操作拒绝。
+OPERATIONDENIED_OPERATIONDENIEDERROR = 'OperationDenied.OperationDeniedError'
+
 # 当前有其他订单正在处于下单过程中，请稍后重试。
 OPERATIONDENIED_OTHERODERINPROCESS = 'OperationDenied.OtherOderInProcess'
 
 # 资源配额超限。
 OPERATIONDENIED_OVERQUOTA = 'OperationDenied.OverQuota'
 
+# 代理地址超限。
+OPERATIONDENIED_PROXYADDRESSLIMITERROR = 'OperationDenied.ProxyAddressLimitError'
+
+# 代理地址未找到。
+OPERATIONDENIED_PROXYADDRESSNOTFUND = 'OperationDenied.ProxyAddressNotFund'
+
+# 代理节点超限。
+OPERATIONDENIED_PROXYNODECOUNTLIMITERROR = 'OperationDenied.ProxyNodeCountLimitError'
+
 # 数据库代理升级任务中，不允许该操作。
 OPERATIONDENIED_PROXYUPGRADETASKSTATUSERROR = 'OperationDenied.ProxyUpgradeTaskStatusError'
 
@@ -476,6 +497,9 @@ OPERATIONDENIED_SUBACCOUNTOPERATIONDENIED = 'OperationDenied.SubAccountOperation
 # 该实例暂不支持退款。
 OPERATIONDENIED_UNSUPPORTREFUNDERROR = 'OperationDenied.UnSupportRefundError'
 
+# 不支持创建代理地址。
+OPERATIONDENIED_UNSUPPORTCREATEADDRESSERROR = 'OperationDenied.UnsupportCreateAddressError'
+
 # 不支持开通审计。
 OPERATIONDENIED_UNSUPPORTOPENAUDITERROR = 'OperationDenied.UnsupportOpenAuditError'
 
@@ -503,6 +527,9 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 未找到数据库实例，请确认您的实例状态是否正常。
 RESOURCENOTFOUND_CDBINSTANCENOTFOUNDERROR = 'ResourceNotFound.CdbInstanceNotFoundError'
 
+# 高可用版实例不存在。
+RESOURCENOTFOUND_INSTANCENOTFOUNDERROR = 'ResourceNotFound.InstanceNotFoundError'
+
 # 该实例不存在。
 RESOURCENOTFOUND_INSTANCENOTFUNDERROR = 'ResourceNotFound.InstanceNotFundError'
 
